@@ -14,17 +14,20 @@ const VALID_OPTIONS = Object.freeze([
   'debug',
   'maxTimeMS',
   'objectIdGetter',
+  'returnOriginal',
   'runValidators',
   'selectPopulatedPaths',
+  'setDefaultsOnInsert',
   'strict',
+  'strictQuery',
   'toJSON',
   'toObject',
+  'typePojoToMixed',
   'useCreateIndex',
   'useFindAndModify',
   'useNewUrlParser',
   'usePushEach',
-  'useUnifiedTopology',
-  'typePojoToMixed'
+  'useUnifiedTopology'
 ]);
 
 module.exports = VALID_OPTIONS;
